@@ -28,9 +28,9 @@ skip_if_no_clipboard <- function() {
 }
 
 
-bench_fun <- function(body,lang = 'r'){
+bench_fun <- function(body,lang = 'r',...){
   
-  body <- sprintf('\n\n%s\n\n',details:::capture.print(body))
+  body <- sprintf('\n\n%s\n\n',details:::capture.print(body,...))
   if(!is.null(lang)){
     body <- sprintf('```%s%s```',lang,body)
   }
